@@ -478,3 +478,24 @@ class Slot:
         from . import lbnightly_settings
 
         return Path(lbnightly_settings().installations.path) / self.id()
+
+    def artifacts(self, stage, platform=""):
+        """
+        Returns the name of the artifacts zip file for a slot.
+
+        @param stage: string describing type of artifacts, only "deployment_dir"
+                      can be used for slots (Project and Package have more options)
+        @param platform: kept for compatibility with Project.artifacts interface,
+                         must be empty for slots
+
+        Raises ValueError if:
+         - stage is not deployment_dir,
+         - platform is specified
+        """
+
+        if stage != "deployment_dir":
+            raise ValueError("Unrecognised stage of the artifact")
+        elif platform != "":
+            raise ValueError("Platform cannot be set for deployment_dir")
+
+        return f"{self.id()}/{stage}.zip"
